@@ -11,4 +11,8 @@ STYLESHEETS = [data('css/bootstrap.min.css'),
                data('css/custom.css'),
                data('cubes.bootstrap.css'),
                ]
-JAVASCRIPTS.append(data('js/bootstrap.min.js'))
+CW_COMPAT_STYLESHEETS = [data('cubes.bootstrap.cw_compat.css'),
+                         ]
+
+JAVASCRIPTS.extend((data('js/bootstrap.min.js'),
+                   data('cubes.bootstrap.js')))
