@@ -69,9 +69,8 @@ def render_body(self, w):
 
 @monkeypatch(NextPrevNavigationComponent)
 def prevnext_div(self, w, type, cssclass, url, title, content):
-    cssclass = u'col-md-6'
-
-    w(u'<li class="%s">' % cssclass)
+    csscls = {'prev':'previous', 'next':'next'}
+    w(u'<li class="%s">' % csscls[type])
     w(u'<a href="%s" title="%s">%s</a>' % (xml_escape(url),
                                            xml_escape(title),
                                            content))
